@@ -1,9 +1,20 @@
+import os
 from pathlib import Path
 
 import fenics as fe
 import numpy as np
 import plotly
 import plotly.graph_objects as go
+import plotly.io as pio
+
+try:
+    _SHOW_PLOT = bool(int(os.getenv("FENICS_PLOTLY_SHOW", 1)))
+except ValueError:
+    _SHOW_PLOT = True
+
+
+def set_renderer(renderer):
+    pio.renderers.default = renderer
 
 
 def savefig(fig, filename, save_config=None):
@@ -519,5 +530,22 @@ def plot(
 
     if filename is not None:
         savefig(fig, filename)
-    if show:
+    if show and _SHOW_PLOT:
         fig.show()
+    return FEniCSPlotFig(fig)
+
+
+class FEniCSPlotFig:
+    def __init__(self, fig):
+        self.figure = fig
+
+    def add_plot(self, fig):
+        data = list(self.figure.data) + list(fig.figure.data)
+        self.figure = go.FigureWidget(data=data, layout=self.figure.layout)
+
+    def show(self):
+        if _SHOW_PLOT:
+            self.figure.show()
+
+    def save(self, filename):
+        savefig(self.figure, filename)
